"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.channel_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel to retrieve."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___GetChannelRequest = GetChannelRequest

@typing.final
class ListChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization containing the channels to list."""
    page_size: builtins.int
    """The maximum number of channels to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListChannelsResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "createdAt desc").
    Default: "id asc".
    Supported fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned channels.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'news' AND id!='channel-123'`

    Filterable fields: ["id", "title"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "order_by", b"order_by", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListChannelsRequest = ListChannelsRequest

@typing.final
class ListChannelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNELS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.channel_pb2.Channel]:
        """List of channels matching the request criteria.
        May be empty if no channels match the criteria or if the organization has no channels.
        """

    def __init__(
        self,
        *,
        channels: collections.abc.Iterable[yandex.cloud.video.v1.channel_pb2.Channel] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channels", b"channels", "next_page_token", b"next_page_token"]) -> None: ...

global___ListChannelsResponse = ListChannelsResponse

@typing.final
class CreateChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization where the channel will be created."""
    title: builtins.str
    """Title of the channel to be displayed in interfaces."""
    description: builtins.str
    """Detailed description of the channel's purpose and content."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as key:value pairs.
        Maximum 64 labels per channel.
        Keys must be lowercase alphanumeric strings with optional hyphens/underscores.
        Values can contain alphanumeric characters and various symbols.
        """

    @property
    def settings(self) -> yandex.cloud.video.v1.channel_pb2.ChannelSettings:
        """Configuration settings for the channel's behavior and features.
        Includes settings for advertisements, content cleanup, and Referer verification.
        """

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: yandex.cloud.video.v1.channel_pb2.ChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "organization_id", b"organization_id", "settings", b"settings", "title", b"title"]) -> None: ...

global___CreateChannelRequest = CreateChannelRequest

@typing.final
class CreateChannelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel being created."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___CreateChannelMetadata = CreateChannelMetadata

@typing.final
class UpdateChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel to update."""
    title: builtins.str
    """New title for the channel."""
    description: builtins.str
    """New description for the channel."""
    default_style_preset_id: builtins.str
    """New default style preset ID for the channel.
    This preset will be applied to new videos created in this channel unless explicitly overridden.
    """
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the channel should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New custom labels for the channel as `key:value` pairs.
        Maximum 64 labels per channel.
        If provided, replaces all existing labels.
        """

    @property
    def settings(self) -> yandex.cloud.video.v1.channel_pb2.ChannelSettings:
        """New configuration settings for the channel's behavior and features."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        default_style_preset_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: yandex.cloud.video.v1.channel_pb2.ChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "default_style_preset_id", b"default_style_preset_id", "description", b"description", "field_mask", b"field_mask", "labels", b"labels", "settings", b"settings", "title", b"title"]) -> None: ...

global___UpdateChannelRequest = UpdateChannelRequest

@typing.final
class UpdateChannelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel being updated."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___UpdateChannelMetadata = UpdateChannelMetadata

@typing.final
class DeleteChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel to delete.
    Deleting a channel will also delete all its content,
    including videos, streams, and related resources.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___DeleteChannelRequest = DeleteChannelRequest

@typing.final
class DeleteChannelMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel being deleted.
    This identifier can be used to track the channel deletion operation.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___DeleteChannelMetadata = DeleteChannelMetadata

@typing.final
class BatchDeleteChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    CHANNEL_IDS_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization containing the channels to delete."""
    @property
    def channel_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of channel IDs to delete.
        Deleting channels will also delete all their content,
        including videos, streams, and related resources.
        """

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        channel_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_ids", b"channel_ids", "organization_id", b"organization_id"]) -> None: ...

global___BatchDeleteChannelsRequest = BatchDeleteChannelsRequest

@typing.final
class BatchDeleteChannelsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_IDS_FIELD_NUMBER: builtins.int
    @property
    def channel_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of channel IDs being deleted.
        This list can be used to track which channels are included
        in the batch deletion operation.
        """

    def __init__(
        self,
        *,
        channel_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_ids", b"channel_ids"]) -> None: ...

global___BatchDeleteChannelsMetadata = BatchDeleteChannelsMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/vrf_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/vrf_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import vrf_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_vrf__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/baremetal/v1alpha/vrf_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/baremetal/v1alpha/vrf.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"9\n\rGetVrfRequest\x12(\n\x06vrf_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"\x9b\x01\n\x0eListVrfRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"c\n\x0fListVrfResponse\x12\x31\n\x04vrfs\x18\x01 \x03(\x0b\x32#.yandex.cloud.baremetal.v1alpha.Vrf\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xdd\x02\n\x10\x43reateVrfRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x8a\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32<.yandex.cloud.baremetal.v1alpha.CreateVrfRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x04\x10\xc8\x01\"#\n\x11\x43reateVrfMetadata\x12\x0e\n\x06vrf_id\x18\x01 \x01(\t\"\x87\x03\n\x10UpdateVrfRequest\x12(\n\x06vrf_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x8a\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32<.yandex.cloud.baremetal.v1alpha.UpdateVrfRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"#\n\x11UpdateVrfMetadata\x12\x0e\n\x06vrf_id\x18\x01 \x01(\t\"<\n\x10\x44\x65leteVrfRequest\x12(\n\x06vrf_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"#\n\x11\x44\x65leteVrfMetadata\x12\x0e\n\x06vrf_id\x18\x01 \x01(\t\"|\n\x18ListVrfOperationsRequest\x12(\n\x06vrf_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"q\n\x19ListVrfOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xdb\x07\n\nVrfService\x12\x83\x01\n\x03Get\x12-.yandex.cloud.baremetal.v1alpha.GetVrfRequest\x1a#.yandex.cloud.baremetal.v1alpha.Vrf\"(\x82\xd3\xe4\x93\x02\"\x12 /baremetal/v1alpha/vrfs/{vrf_id}\x12\x88\x01\n\x04List\x12..yandex.cloud.baremetal.v1alpha.ListVrfRequest\x1a/.yandex.cloud.baremetal.v1alpha.ListVrfResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/baremetal/v1alpha/vrfs\x12\x9d\x01\n\x06\x43reate\x12\x30.yandex.cloud.baremetal.v1alpha.CreateVrfRequest\x1a!.yandex.cloud.operation.Operation\">\xb2\xd2*\x18\n\x11\x43reateVrfMetadata\x12\x03Vrf\x82\xd3\xe4\x93\x02\x1c\"\x17/baremetal/v1alpha/vrfs:\x01*\x12\xa6\x01\n\x06Update\x12\x30.yandex.cloud.baremetal.v1alpha.UpdateVrfRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x18\n\x11UpdateVrfMetadata\x12\x03Vrf\x82\xd3\xe4\x93\x02%2 /baremetal/v1alpha/vrfs/{vrf_id}:\x01*\x12\xb5\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.baremetal.v1alpha.DeleteVrfRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2**\n\x11\x44\x65leteVrfMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\"* /baremetal/v1alpha/vrfs/{vrf_id}\x12\xba\x01\n\x0eListOperations\x12\x38.yandex.cloud.baremetal.v1alpha.ListVrfOperationsRequest\x1a\x39.yandex.cloud.baremetal.v1alpha.ListVrfOperationsResponse\"3\x82\xd3\xe4\x93\x02-\x12+/baremetal/v1alpha/vrfs/{vrf_id}/operationsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.vrf_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETVRFREQUEST'].fields_by_name['vrf_id']._loaded_options = None
  _globals['_GETVRFREQUEST'].fields_by_name['vrf_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTVRFREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTVRFREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTVRFREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTVRFREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_CREATEVRFREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEVRFREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEVRFREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEVRFREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_CREATEVRFREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEVRFREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_CREATEVRFREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEVRFREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEVRFREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEVRFREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEVRFREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEVRFREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['vrf_id']._loaded_options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['vrf_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEVRFREQUEST'].fields_by_name['vrf_id']._loaded_options = None
  _globals['_DELETEVRFREQUEST'].fields_by_name['vrf_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTVRFOPERATIONSREQUEST'].fields_by_name['vrf_id']._loaded_options = None
  _globals['_LISTVRFOPERATIONSREQUEST'].fields_by_name['vrf_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTVRFOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTVRFOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_VRFSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_VRFSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\"\022 /baremetal/v1alpha/vrfs/{vrf_id}'
  _globals['_VRFSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_VRFSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/baremetal/v1alpha/vrfs'
  _globals['_VRFSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_VRFSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\030\n\021CreateVrfMetadata\022\003Vrf\202\323\344\223\002\034\"\027/baremetal/v1alpha/vrfs:\001*'
  _globals['_VRFSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_VRFSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\030\n\021UpdateVrfMetadata\022\003Vrf\202\323\344\223\002%2 /baremetal/v1alpha/vrfs/{vrf_id}:\001*'
  _globals['_VRFSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_VRFSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322**\n\021DeleteVrfMetadata\022\025google.protobuf.Empty\202\323\344\223\002\"* /baremetal/v1alpha/vrfs/{vrf_id}'
  _globals['_VRFSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_VRFSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002-\022+/baremetal/v1alpha/vrfs/{vrf_id}/operations'
  _globals['_GETVRFREQUEST']._serialized_start=295
  _globals['_GETVRFREQUEST']._serialized_end=352
  _globals['_LISTVRFREQUEST']._serialized_start=355
  _globals['_LISTVRFREQUEST']._serialized_end=510
  _globals['_LISTVRFRESPONSE']._serialized_start=512
  _globals['_LISTVRFRESPONSE']._serialized_end=611
  _globals['_CREATEVRFREQUEST']._serialized_start=614
  _globals['_CREATEVRFREQUEST']._serialized_end=963
  _globals['_CREATEVRFREQUEST_LABELSENTRY']._serialized_start=911
  _globals['_CREATEVRFREQUEST_LABELSENTRY']._serialized_end=956
  _globals['_CREATEVRFMETADATA']._serialized_start=965
  _globals['_CREATEVRFMETADATA']._serialized_end=1000
  _globals['_UPDATEVRFREQUEST']._serialized_start=1003
  _globals['_UPDATEVRFREQUEST']._serialized_end=1394
  _globals['_UPDATEVRFREQUEST_LABELSENTRY']._serialized_start=911
  _globals['_UPDATEVRFREQUEST_LABELSENTRY']._serialized_end=956
  _globals['_UPDATEVRFMETADATA']._serialized_start=1396
  _globals['_UPDATEVRFMETADATA']._serialized_end=1431
  _globals['_DELETEVRFREQUEST']._serialized_start=1433
  _globals['_DELETEVRFREQUEST']._serialized_end=1493
  _globals['_DELETEVRFMETADATA']._serialized_start=1495
  _globals['_DELETEVRFMETADATA']._serialized_end=1530
  _globals['_LISTVRFOPERATIONSREQUEST']._serialized_start=1532
  _globals['_LISTVRFOPERATIONSREQUEST']._serialized_end=1656
  _globals['_LISTVRFOPERATIONSRESPONSE']._serialized_start=1658
  _globals['_LISTVRFOPERATIONSRESPONSE']._serialized_end=1771
  _globals['_VRFSERVICE']._serialized_start=1774
  _globals['_VRFSERVICE']._serialized_end=2761
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.config.config_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    YAML_STRING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a config in."""
    yaml_string: builtins.str
    """Config content provided as a string in YAML format."""
    name: builtins.str
    """Name of the config."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        yaml_string: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "yaml_string", b"yaml_string"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "folder_id", b"folder_id", "name", b"name", "yaml_string", b"yaml_string"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["yaml_string"] | None: ...

global___CreateConfigRequest = CreateConfigRequest

@typing.final
class CreateConfigMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_ID_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    """ID of the config that is being created."""
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["config_id", b"config_id"]) -> None: ...

global___CreateConfigMetadata = CreateConfigMetadata

@typing.final
class GetConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_ID_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    """ID of the config to return."""
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["config_id", b"config_id"]) -> None: ...

global___GetConfigRequest = GetConfigRequest

@typing.final
class ListConfigsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list configs in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListConfigsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListConfigsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters tests listed in the response."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListConfigsRequest = ListConfigsRequest

@typing.final
class ListConfigsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListConfigsRequest.page_size], use `next_page_token` as the value
    for the [ListConfigsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.config.config_pb2.Config]:
        """List of configs in the specified folder."""

    def __init__(
        self,
        *,
        configs: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.config.config_pb2.Config] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["configs", b"configs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListConfigsResponse = ListConfigsResponse

@typing.final
class DeleteConfigRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_ID_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    """ID of the config to deleted."""
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["config_id", b"config_id"]) -> None: ...

global___DeleteConfigRequest = DeleteConfigRequest

@typing.final
class DeleteConfigMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_ID_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    """ID of the config that is being deleted."""
    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["config_id", b"config_id"]) -> None: ...

global___DeleteConfigMetadata = DeleteConfigMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.empty_pb2
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TLSParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    @property
    def disabled(self) -> google.protobuf.empty_pb2.Empty: ...
    @property
    def tls(self) -> global___TLSConfig: ...
    def __init__(
        self,
        *,
        disabled: google.protobuf.empty_pb2.Empty | None = ...,
        tls: global___TLSConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["disabled", b"disabled", "tls", b"tls", "tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "tls", b"tls", "tls_mode", b"tls_mode"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["tls_mode", b"tls_mode"]) -> typing.Literal["disabled", "tls"] | None: ...

global___TLSParams = TLSParams

@typing.final
class TLSConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    ca_certificate: builtins.str
    def __init__(
        self,
        *,
        ca_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ca_certificate", b"ca_certificate"]) -> None: ...

global___TLSConfig = TLSConfig

@typing.final
class Password(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_FIELD_NUMBER: builtins.int
    PASSWORD_GENERATION_OPTIONS_FIELD_NUMBER: builtins.int
    LOCKBOX_SECRET_KEY_FIELD_NUMBER: builtins.int
    raw: builtins.str
    """When creating/updating Password, the field "raw" is mutually exclusive
    with "password_generation_options". In order to switch to the "raw"
    password you have to explicitly clear the "password_generation_options"
    field.
    """
    lockbox_secret_key: builtins.str
    """Read-only. Do not fill this field in create/update requests."""
    @property
    def password_generation_options(self) -> global___PasswordGenerationOptions:
        """When creating/updating Password, the field "password_generation_options"
        is mutually exclusive with "raw". In order to switch to the
        "password_generation_options" you have to explicitly clear the "raw"
        field.
        """

    def __init__(
        self,
        *,
        raw: builtins.str = ...,
        password_generation_options: global___PasswordGenerationOptions | None = ...,
        lockbox_secret_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lockbox_secret_key", b"lockbox_secret_key", "password_generation_options", b"password_generation_options", "secret_key", b"secret_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["lockbox_secret_key", b"lockbox_secret_key", "password_generation_options", b"password_generation_options", "raw", b"raw", "secret_key", b"secret_key"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["secret_key", b"secret_key"]) -> typing.Literal["lockbox_secret_key"] | None: ...

global___Password = Password

@typing.final
class PasswordGenerationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COOKIE_FIELD_NUMBER: builtins.int
    LOCKBOX_PASSWORD_GENERATION_OPTIONS_FIELD_NUMBER: builtins.int
    cookie: builtins.str
    """Cookie is an arbitrary non-sensitive string that is saved with the
    password. When updating PasswordGenerationOptions, if the cookie passed
    in the update request differs from the cookie in the current
    PasswordGenerationOptions, the password will be re-generated. If the
    same cookie is passed, the password will not change.
    """
    @property
    def lockbox_password_generation_options(self) -> global___LockboxPasswordGenerationOptions: ...
    def __init__(
        self,
        *,
        cookie: builtins.str = ...,
        lockbox_password_generation_options: global___LockboxPasswordGenerationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lockbox_password_generation_options", b"lockbox_password_generation_options", "password_generation_options", b"password_generation_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cookie", b"cookie", "lockbox_password_generation_options", b"lockbox_password_generation_options", "password_generation_options", b"password_generation_options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["password_generation_options", b"password_generation_options"]) -> typing.Literal["lockbox_password_generation_options"] | None: ...

global___PasswordGenerationOptions = PasswordGenerationOptions

@typing.final
class LockboxPasswordGenerationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LENGTH_FIELD_NUMBER: builtins.int
    INCLUDE_UPPERCASE_FIELD_NUMBER: builtins.int
    INCLUDE_LOWERCASE_FIELD_NUMBER: builtins.int
    INCLUDE_DIGITS_FIELD_NUMBER: builtins.int
    INCLUDE_PUNCTUATION_FIELD_NUMBER: builtins.int
    INCLUDED_PUNCTUATION_FIELD_NUMBER: builtins.int
    EXCLUDED_PUNCTUATION_FIELD_NUMBER: builtins.int
    length: builtins.int
    """password length; by default, a reasonable length will be decided"""
    included_punctuation: builtins.str
    """If include_punctuation is true, one of these two fields (not both) may be used optionally to customize the punctuation:
    a string of specific punctuation characters to use
    """
    excluded_punctuation: builtins.str
    """a string of punctuation characters to exclude from the default"""
    @property
    def include_uppercase(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """whether at least one A..Z character is included in the password, true by default"""

    @property
    def include_lowercase(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """whether at least one a..z character is included in the password, true by default"""

    @property
    def include_digits(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """whether at least one 0..9 character is included in the password, true by default"""

    @property
    def include_punctuation(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """whether at least one punctuation character is included in the password, true by default
        punctuation characters by default: !"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~
        to customize the punctuation characters, see included_punctuation and excluded_punctuation below
        """

    def __init__(
        self,
        *,
        length: builtins.int = ...,
        include_uppercase: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        include_lowercase: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        include_digits: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        include_punctuation: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        included_punctuation: builtins.str = ...,
        excluded_punctuation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["include_digits", b"include_digits", "include_lowercase", b"include_lowercase", "include_punctuation", b"include_punctuation", "include_uppercase", b"include_uppercase"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["excluded_punctuation", b"excluded_punctuation", "include_digits", b"include_digits", "include_lowercase", b"include_lowercase", "include_punctuation", b"include_punctuation", "include_uppercase", b"include_uppercase", "included_punctuation", b"included_punctuation", "length", b"length"]) -> None: ...

global___LockboxPasswordGenerationOptions = LockboxPasswordGenerationOptions

@typing.final
class UserPasswordAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    user: builtins.str
    @property
    def password(self) -> global___Password: ...
    def __init__(
        self,
        *,
        user: builtins.str = ...,
        password: global___Password | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["password", b"password", "user", b"user"]) -> None: ...

global___UserPasswordAuth = UserPasswordAuth



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.datasphere.v1.node_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class NodeServiceStub:
    """A set of methods for managing Node resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Execute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionRequest,
        yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionResponse,
    ]
    """Executes deployed Node."""

    ExecuteAlias: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionRequest,
        yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionResponse,
    ]
    """Executes NodeAlias requests."""

class NodeServiceAsyncStub:
    """A set of methods for managing Node resources."""

    Execute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionRequest,
        yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionResponse,
    ]
    """Executes deployed Node."""

    ExecuteAlias: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionRequest,
        yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionResponse,
    ]
    """Executes NodeAlias requests."""

class NodeServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Node resources."""

    @abc.abstractmethod
    def Execute(
        self,
        request: yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.node_service_pb2.NodeExecutionResponse]]:
        """Executes deployed Node."""

    @abc.abstractmethod
    def ExecuteAlias(
        self,
        request: yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.node_service_pb2.AliasExecutionResponse]]:
        """Executes NodeAlias requests."""

def add_NodeServiceServicer_to_server(servicer: NodeServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/oauth_client_secret_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/oauth_client_secret_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.iam.v1 import oauth_client_secret_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_oauth__client__secret__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/iam/v1/oauth_client_secret_service.proto\x12\x13yandex.cloud.iam.v1\x1a-yandex/cloud/iam/v1/oauth_client_secret.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"K\n\x1bGetOAuthClientSecretRequest\x12,\n\x16oauth_client_secret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x85\x01\n\x1dListOAuthClientSecretsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12%\n\x0foauth_client_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x7f\n\x1eListOAuthClientSecretsResponse\x12\x44\n\x14oauth_client_secrets\x18\x01 \x03(\x0b\x32&.yandex.cloud.iam.v1.OAuthClientSecret\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x1e\x43reateOAuthClientSecretRequest\x12%\n\x0foauth_client_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"A\n\x1f\x43reateOAuthClientSecretMetadata\x12\x1e\n\x16oauth_client_secret_id\x18\x01 \x01(\t\"|\n\x1f\x43reateOAuthClientSecretResponse\x12\x43\n\x13oauth_client_secret\x18\x01 \x01(\x0b\x32&.yandex.cloud.iam.v1.OAuthClientSecret\x12\x14\n\x0csecret_value\x18\x02 \x01(\t\"N\n\x1e\x44\x65leteOAuthClientSecretRequest\x12,\n\x16oauth_client_secret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"A\n\x1f\x44\x65leteOAuthClientSecretMetadata\x12\x1e\n\x16oauth_client_secret_id\x18\x01 \x01(\t2\xfb\x05\n\x18OAuthClientSecretService\x12\x9c\x01\n\x03Get\x12\x30.yandex.cloud.iam.v1.GetOAuthClientSecretRequest\x1a&.yandex.cloud.iam.v1.OAuthClientSecret\";\x82\xd3\xe4\x93\x02\x35\x12\x33/iam/v1/oauthClientSecrets/{oauth_client_secret_id}\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.iam.v1.ListOAuthClientSecretsRequest\x1a\x33.yandex.cloud.iam.v1.ListOAuthClientSecretsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/iam/v1/oauthClientSecrets\x12\xcd\x01\n\x06\x43reate\x12\x33.yandex.cloud.iam.v1.CreateOAuthClientSecretRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*B\n\x1f\x43reateOAuthClientSecretMetadata\x12\x1f\x43reateOAuthClientSecretResponse\x82\xd3\xe4\x93\x02\x1f\"\x1a/iam/v1/oauthClientSecrets:\x01*\x12\xd9\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.iam.v1.DeleteOAuthClientSecretRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*8\n\x1f\x44\x65leteOAuthClientSecretMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35*3/iam/v1/oauthClientSecrets/{oauth_client_secret_id}BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.oauth_client_secret_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._loaded_options = None
  _globals['_GETOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._loaded_options = None
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0025\0223/iam/v1/oauthClientSecrets/{oauth_client_secret_id}'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/iam/v1/oauthClientSecrets'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*B\n\037CreateOAuthClientSecretMetadata\022\037CreateOAuthClientSecretResponse\202\323\344\223\002\037\"\032/iam/v1/oauthClientSecrets:\001*'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*8\n\037DeleteOAuthClientSecretMetadata\022\025google.protobuf.Empty\202\323\344\223\0025*3/iam/v1/oauthClientSecrets/{oauth_client_secret_id}'
  _globals['_GETOAUTHCLIENTSECRETREQUEST']._serialized_start=260
  _globals['_GETOAUTHCLIENTSECRETREQUEST']._serialized_end=335
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST']._serialized_start=338
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST']._serialized_end=471
  _globals['_LISTOAUTHCLIENTSECRETSRESPONSE']._serialized_start=473
  _globals['_LISTOAUTHCLIENTSECRETSRESPONSE']._serialized_end=600
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST']._serialized_start=602
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST']._serialized_end=705
  _globals['_CREATEOAUTHCLIENTSECRETMETADATA']._serialized_start=707
  _globals['_CREATEOAUTHCLIENTSECRETMETADATA']._serialized_end=772
  _globals['_CREATEOAUTHCLIENTSECRETRESPONSE']._serialized_start=774
  _globals['_CREATEOAUTHCLIENTSECRETRESPONSE']._serialized_end=898
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST']._serialized_start=900
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST']._serialized_end=978
  _globals['_DELETEOAUTHCLIENTSECRETMETADATA']._serialized_start=980
  _globals['_DELETEOAUTHCLIENTSECRETMETADATA']._serialized_end=1045
  _globals['_OAUTHCLIENTSECRETSERVICE']._serialized_start=1048
  _globals['_OAUTHCLIENTSECRETSERVICE']._serialized_end=1811
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HardwarePool(google.protobuf.message.Message):
    """A HardwarePool resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the hardware pool."""
    zone_id: builtins.str
    """ID of the zone where the hardware pool is located.

    To get the zone ID use a [ZoneService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "zone_id", b"zone_id"]) -> None: ...

global___HardwarePool = HardwarePool



# pylint: disable=no-member
# pylint: disable=duplicate-code
# mypy: ignore-errors
import logging
import random
from dataclasses import dataclass
from typing import Dict, List, Optional

import yandex.cloud.spark.v1.cluster_pb2 as cluster_pb
import yandex.cloud.spark.v1.cluster_service_pb2 as cluster_service_pb
import yandex.cloud.spark.v1.cluster_service_pb2_grpc as cluster_service_grpc_pb
import yandex.cloud.spark.v1.job_pb2 as job_pb
import yandex.cloud.spark.v1.job_service_pb2 as job_service_pb
import yandex.cloud.spark.v1.job_service_pb2_grpc as job_service_grpc_pb
import yandex.cloud.spark.v1.maintenance_pb2 as maintenance_pb


@dataclass
class SparkClusterParameters:
    """
    Spark Cluster Parameters.

    Constructor arguments:
    :param folder_id: ID of the folder in which cluster should be created.
    :type folder_id: str
    :param service_account_id: Service account that will be used to access
        cloud resources.
    :type service_account_id: str
    :param name: Name of the Spark cluster. The name must be unique within
        the folder.
    :type name: str, optional
    :param description: Text description of the Spark cluster.
    :type description: str, optional
    :param labels: Cluster labels as key:value pairs.
    :type labels: Dict[str, str], optional
    :param subnet_ids: Network subnets.
    :type subnet_ids: List[str]
    :param security_group_ids: Network security groups.
    :type security_group_ids: List[str]
    :param deletion_protection: Deletion Protection inhibits deletion of
        the cluster.
    :type deletion_protection: bool
    :param driver_pool_resource_preset: Resource preset ID for Driver pool.
    :type driver_pool_resource_preset: str
    :param driver_pool_size: Node count for Driver pool with fixed size.
    :type driver_pool_size: int, optional
    :param driver_pool_min_size: Minimum node count for Driver pool with
        autoscaling.
    :type driver_pool_min_size: int, optional
    :param driver_pool_max_size: Maximum node count for Driver pool with
        autoscaling.
    :type driver_pool_max_size: int, optional
    :param executor_pool_resource_preset: Resource preset ID for Executor
        pool.
    :type executor_pool_resource_preset: str
    :param executor_pool_size: Node count for Executor pool with fixed size.
    :type executor_pool_size: int, optional
    :param executor_pool_min_size: Minimum node count for Executor pool
        with autoscaling.
    :type executor_pool_min_size: int, optional
    :param executor_pool_max_size: Maximum node count for Executor pool
        with autoscaling.
    :type executor_pool_max_size: int, optional
    :param logging_enabled: Enable sending logs to Cloud Logging.
    :type logging_enabled: bool, optional
    :param log_group_id: Log Group ID in Cloud Logging to store cluster
        logs.
    :type log_group_id: str, optional
    :param log_folder_id: Folder ID to store cluster logs in default log
        group.
    :type log_folder_id: str, optional
    :param history_server_enabled: Enable Spark History Server.
    :type history_server_enabled: bool, optional
    :param pip_packages: Python packages that need to be installed using pip
        (in pip requirement format).
    :type pip_packages: List[str], optional
    :param deb_packages: Deb-packages that need to be installed using system
        package manager.
    :type deb_packages: List[str], optional
    :param metastore_cluster_id: Metastore cluster ID for default spark
        configuration.
    :type metastore_cluster_id: str, optional
    :param maintenance_weekday: Weekday number for maintenance operations.
        From 1 - Monday to 7 - Sunday.
    :type maintenance_weekday: int, optional
    :param maintenance_hour: Hour of the day for maintenance oprerations.
        From 1 to 24.
    :type maintenance_hour: int, optional
    """

    # pylint: disable=too-many-instance-attributes

    folder_id: str
    service_account_id: str
    name: Optional[str] = None
    description: str = ""
    labels: Optional[Dict[str, str]] = None
    subnet_ids: Optional[List[str]] = None
    security_group_ids: Optional[List[str]] = None
    deletion_protection: bool = False
    driver_pool_resource_preset: str = ""
    driver_pool_size: int = 0
    driver_pool_min_size: int = 0
    driver_pool_max_size: int = 0
    executor_pool_resource_preset: str = ""
    executor_pool_size: int = 0
    executor_pool_min_size: int = 0
    executor_pool_max_size: int = 0
    logging_enabled: bool = True
    log_group_id: Optional[str] = None
    log_folder_id: Optional[str] = None
    history_server_enabled: bool = True
    pip_packages: Optional[List[str]] = None
    deb_packages: Optional[List[str]] = None
    metastore_cluster_id: str = ""
    maintenance_weekday: Optional[int] = None
    maintenance_hour: Optional[int] = None


@dataclass
class SparkJobParameters:
    """
    Spark Job Parameters.

    Constructor arguments:
    :param name: Name of the job.
    :type name: str, optional
    :param main_jar_file_uri: URI of the jar file that contains the main
        class.
    :type main_jar_file_uri: str
    :param main_class: Name of the main class of the job.
    :type main_class: str, optional
    :param args: Arguments to be passed to the job.
    :type args: List[str], optional
    :param properties: Spark properties for the job.
    :type properties: Dist[str, str], optional
    :param packages: List of maven coordinates of jars to include on the
        driver and executor classpaths.
    :type packages: List[str], optional
    :param file_uris: URIs of files to be placed in the working directory.
    :type file_uris: List[str], optional
    :param jar_file_uris: URIs of JAR dependencies to be added to the
        CLASSPATH.
    :type jar_archive_uris: List[str], optional
    :param archive_uris: URIs of archives to be extracted into the working
        directory.
    :type archive_uris: List[str], optional
    :param repositories: List of additional remote repositories to search
        for the maven coordinates given with --packages.
    :type repositories: List[str], optional
    :param exclude_packages: List of groupId:artifactId, to exclude while
        resolving the dependencies provided in --packages to avoid
        dependency conflicts.
    :type exclude_packages: List[str], optional
    """

    # pylint: disable=too-many-instance-attributes

    name: str = ""
    main_jar_file_uri: str = ""
    main_class: str = ""
    args: Optional[List[str]] = None
    properties: Optional[Dict[str, str]] = None
    packages: Optional[List[str]] = None
    file_uris: Optional[List[str]] = None
    jar_file_uris: Optional[List[str]] = None
    archive_uris: Optional[List[str]] = None
    repositories: Optional[List[str]] = None
    exclude_packages: Optional[List[str]] = None


@dataclass
class PysparkJobParameters:
    """
    Pyspark Job Parameters.

    Constructor arguments:
    :param name: Name of the job.
    :type name: str, optional
    :param main_python_file_uri: URI of the main Python file.
    :type main_python_file_uri: str
    :param args: Arguments to be passed to the job.
    :type args: List[str], optional
    :param properties: Spark properties for the job.
    :type properties: Dist[str, str], optional
    :param packages: List of maven coordinates of jars to include on the
        driver and executor classpaths.
    :type packages: List[str], optional
    :param file_uris: URIs of files to be placed in the working directory.
    :type file_uris: List[str], optional
    :param python_file_uris: URIs of python files used in the job.
    :type python_file_uris: List[str], optional
    :param jar_file_uris: URIs of JAR dependencies to be added to the
        CLASSPATH.
    :type jar_file_uris: List[str], optional
    :param archive_uris: URIs of archives to be extracted into the working
        directory.
    :type archive_uris: List[str], optional
    :param repositories: List of additional remote repositories to search
        for the maven coordinates given with --packages.
    :type repositories: List[str], optional
    :param exclude_packages: List of groupId:artifactId, to exclude while
        resolving the dependencies provided in --packages to avoid
        dependency conflicts.
    :type exclude_packages: List[str], optional
    """

    # pylint: disable=too-many-instance-attributes

    name: str = ""
    main_python_file_uri: str = ""
    args: Optional[List[str]] = None
    properties: Optional[Dict[str, str]] = None
    packages: Optional[List[str]] = None
    file_uris: Optional[List[str]] = None
    python_file_uris: Optional[List[str]] = None
    jar_file_uris: Optional[List[str]] = None
    archive_uris: Optional[List[str]] = None
    repositories: Optional[List[str]] = None
    exclude_packages: Optional[List[str]] = None


class Spark:
    """
    A base hook for Yandex.Cloud Managed Service for Apache Spark

    :param logger: Logger object
    :type logger: Optional[logging.Logger]
    :param sdk: SDK object. Normally is being set by Wrappers constructor
    :type sdk: yandexcloud.SDK
    """

    def __init__(self, logger=None, sdk=None):
        self.sdk = sdk or self.sdk
        self.log = logger
        if not self.log:
            self.log = logging.getLogger()
            self.log.addHandler(logging.NullHandler())
        self.cluster_id = None

    def create_cluster(self, spec: SparkClusterParameters) -> str:
        """
        Create cluster.

        :param spec: Cluster parameters.
        :type spec: SparkClusterParameters

        :return: Operation result
        :rtype: OperationResult
        """

        # pylint: disable=too-many-branches

        if not spec.folder_id:
            raise RuntimeError("Folder ID must be specified to create cluster.")

        if not spec.name:
            random_int = random.randint(0, 999)
            spec.name = f"spark-{random_int}"

        if spec.driver_pool_max_size > 0:
            driver_pool = cluster_pb.ResourcePool(
                resource_preset_id=spec.driver_pool_resource_preset,
                scale_policy=cluster_pb.ScalePolicy(
                    auto_scale=cluster_pb.ScalePolicy.AutoScale(
                        min_size=spec.driver_pool_min_size,
                        max_size=spec.driver_pool_max_size,
                    ),
                ),
            )
        elif spec.driver_pool_size > 0:
            driver_pool = cluster_pb.ResourcePool(
                resource_preset_id=spec.driver_pool_resource_preset,
                scale_policy=cluster_pb.ScalePolicy(
                    fixed_scale=cluster_pb.ScalePolicy.FixedScale(
                        size=spec.driver_pool_size,
                    ),
                ),
            )
        else:
            raise RuntimeError("Driver pool size is not specified.")

        if spec.executor_pool_max_size > 0:
            executor_pool = cluster_pb.ResourcePool(
                resource_preset_id=spec.executor_pool_resource_preset,
                scale_policy=cluster_pb.ScalePolicy(
                    auto_scale=cluster_pb.ScalePolicy.AutoScale(
                        min_size=spec.executor_pool_min_size,
                        max_size=spec.executor_pool_max_size,
                    ),
                ),
            )
        elif spec.executor_pool_size > 0:
            executor_pool = cluster_pb.ResourcePool(
                resource_preset_id=spec.executor_pool_resource_preset,
                scale_policy=cluster_pb.ScalePolicy(
                    fixed_scale=cluster_pb.ScalePolicy.FixedScale(
                        size=spec.executor_pool_size,
                    ),
                ),
            )
        else:
            raise RuntimeError("Executor pool size is not specified.")

        if spec.log_group_id is not None:
            logging_config = cluster_pb.LoggingConfig(
                enabled=True,
                log_group_id=spec.log_group_id,
            )
        elif spec.log_folder_id is not None:
            logging_config = cluster_pb.LoggingConfig(
                enabled=True,
                folder_id=spec.log_folder_id,
            )
        elif spec.logging_enabled:
            logging_config = cluster_pb.LoggingConfig(
                enabled=True,
                folder_id=spec.folder_id,
            )
        else:
            logging_config = cluster_pb.LoggingConfig(
                enabled=False,
            )

        if spec.maintenance_hour is not None and spec.maintenance_weekday is not None:
            if not 1 <= spec.maintenance_hour <= 24:
                raise RuntimeError("Maintenance hour is not valid.")

            if not 0 <= spec.maintenance_weekday <= 7:
                raise RuntimeError("Maintenance weekday is not valid.")

            maintenance_window = maintenance_pb.MaintenanceWindow(
                weekly_maintenance_window=maintenance_pb.WeeklyMaintenanceWindow(
                    day=spec.maintenance_weekday,
                    hour=spec.maintenance_hour,
                ),
            )
        else:
            maintenance_window = maintenance_pb.MaintenanceWindow(
                anytime=maintenance_pb.AnytimeMaintenanceWindow(),
            )

        request = cluster_service_pb.CreateClusterRequest(
            folder_id=spec.folder_id,
            name=spec.name,
            description=spec.description,
            labels=spec.labels,
            config=cluster_pb.ClusterConfig(
                resource_pools=cluster_pb.ResourcePools(
                    driver=driver_pool,
                    executor=executor_pool,
                ),
                history_server=cluster_pb.HistoryServerConfig(
                    enabled=spec.history_server_enabled,
                ),
                dependencies=cluster_pb.Dependencies(
                    pip_packages=spec.pip_packages,
                    deb_packages=spec.deb_packages,
                ),
                metastore=cluster_pb.Metastore(
                    cluster_id=spec.metastore_cluster_id,
                ),
            ),
            network=cluster_pb.NetworkConfig(
                subnet_ids=spec.subnet_ids,
                security_group_ids=spec.security_group_ids,
            ),
            deletion_protection=spec.deletion_protection,
            service_account_id=spec.service_account_id,
            logging=logging_config,
            maintenance_window=maintenance_window,
        )

        self.log.info("Creating Spark cluster. Request: %s.", request)

        result = self.sdk.create_operation_and_get_result(
            request,
            service=cluster_service_grpc_pb.ClusterServiceStub,
            method_name="Create",
            response_type=cluster_pb.Cluster,
            meta_type=cluster_service_pb.CreateClusterMetadata,
        )

        self.cluster_id = result.response.id
        return result

    def delete_cluster(self, cluster_id: Optional[str] = None):
        """
        Delete cluster.

        :param cluster_id: ID of the cluster to remove.
        :type cluster_id: str, optional

        :return: Operation result
        :rtype: OperationResult
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        request = cluster_service_pb.DeleteClusterRequest(cluster_id=cluster_id)

        self.log.info("Deleting Spark cluster. Request: %s.", request)

        return self.sdk.create_operation_and_get_result(
            request,
            service=cluster_service_grpc_pb.ClusterServiceStub,
            method_name="Delete",
            meta_type=cluster_service_pb.DeleteClusterMetadata,
        )

    def stop_cluster(self, cluster_id: Optional[str] = None):
        """
        Stop cluster.

        :param cluster_id: ID of the cluster to stop.
        :type cluster_id: str, optional

        :return: Operation result
        :rtype: OperationResult
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        request = cluster_service_pb.StopClusterRequest(cluster_id=cluster_id)

        self.log.info("Stopping Spark cluster. Request: %s.", request)

        return self.sdk.create_operation_and_get_result(
            request,
            service=cluster_service_grpc_pb.ClusterServiceStub,
            method_name="Stop",
            meta_type=cluster_service_pb.StopClusterMetadata,
        )

    def start_cluster(self, cluster_id: Optional[str] = None):
        """
        Start cluster.

        :param cluster_id: ID of the cluster to start.
        :type cluster_id: str, optional

        :return: Operation result
        :rtype: OperationResult
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        request = cluster_service_pb.StartClusterRequest(cluster_id=cluster_id)

        self.log.info("Starting Spark cluster. Request: %s.", request)

        return self.sdk.create_operation_and_get_result(
            request,
            service=cluster_service_grpc_pb.ClusterServiceStub,
            method_name="Start",
            meta_type=cluster_service_pb.StartClusterMetadata,
        )

    def create_spark_job(self, spec: SparkJobParameters, cluster_id: Optional[str] = None):
        """
        Run spark job.

        :param cluster_id: ID of the cluster.
        :type cluster_id: str, optional
        :param spec: Job parameters.
        :type spec: SparkJobParameters

        :return: Operation result
        :rtype: OperationResult
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        request = job_service_pb.CreateJobRequest(
            cluster_id=cluster_id,
            name=spec.name,
            spark_job=job_pb.SparkJob(
                main_jar_file_uri=spec.main_jar_file_uri,
                main_class=spec.main_class,
                args=spec.args,
                properties=spec.properties,
                packages=spec.packages,
                file_uris=spec.file_uris,
                jar_file_uris=spec.jar_file_uris,
                archive_uris=spec.archive_uris,
                repositories=spec.repositories,
                exclude_packages=spec.exclude_packages,
            ),
        )

        self.log.info("Running Spark job. Request: %s.", request)

        return self.sdk.create_operation_and_get_result(
            request,
            service=job_service_grpc_pb.JobServiceStub,
            method_name="Create",
            response_type=job_pb.Job,
            meta_type=job_service_pb.CreateJobMetadata,
        )

    def create_pyspark_job(self, spec: PysparkJobParameters, cluster_id: Optional[str] = None):
        """
        Run Pyspark job on the cluster.

        :param cluster_id: ID of the cluster.
        :type cluster_id: str, optional
        :param spec: Job parameters.
        :type spec: PysparkJobParameters

        :return: Operation result
        :rtype: OperationResult
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        request = job_service_pb.CreateJobRequest(
            cluster_id=cluster_id,
            name=spec.name,
            pyspark_job=job_pb.PysparkJob(
                main_python_file_uri=spec.main_python_file_uri,
                args=spec.args,
                properties=spec.properties,
                packages=spec.packages,
                file_uris=spec.file_uris,
                python_file_uris=spec.python_file_uris,
                jar_file_uris=spec.jar_file_uris,
                archive_uris=spec.archive_uris,
                repositories=spec.repositories,
                exclude_packages=spec.exclude_packages,
            ),
        )

        self.log.info("Running Pyspark job. Request: %s.", request)

        return self.sdk.create_operation_and_get_result(
            request,
            service=job_service_grpc_pb.JobServiceStub,
            method_name="Create",
            response_type=job_pb.Job,
            meta_type=job_service_pb.CreateJobMetadata,
        )

    def get_job(self, job_id: str, cluster_id: Optional[str] = None):
        """
        Get job info.

        :param cluster_id: ID of the cluster.
        :type cluster_id: str, optional
        :param job_id: ID of the job.
        :type job_id: str

        :return: Job info, job status name
        :rtype: Tuple[Job, str]
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        request = job_service_pb.GetJobRequest(
            cluster_id=cluster_id,
            job_id=job_id,
        )
        job = self.sdk.client(job_service_grpc_pb.JobServiceStub).Get(request)
        return job, job_pb.Job.Status.Name(job.status)

    def get_job_log(self, job_id: str, cluster_id: Optional[str] = None):
        """
        Get job log.

        :param cluster_id: ID of the cluster.
        :type cluster_id: str, optional
        :param job_id: ID of the job.
        :type job_id: str

        :return: Job log
        :rtype: List[str]
        """
        cluster_id = cluster_id or self.cluster_id
        if not cluster_id:
            raise RuntimeError("Cluster id must be specified.")

        result = []
        page_token = ""

        while True:
            request = job_service_pb.ListJobLogRequest(
                cluster_id=cluster_id,
                job_id=job_id,
                page_token=page_token,
            )
            page = self.sdk.client(job_service_grpc_pb.JobServiceStub).ListLog(request)
            if page.content:
                result.extend(page.content.split("\n"))
            if page.next_page_token and page_token != page.next_page_token:
                page_token = page.next_page_token
            else:
                break
        return result



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.vision.v1.primitives_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FaceAnnotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FACES_FIELD_NUMBER: builtins.int
    @property
    def faces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Face]:
        """An array of detected faces for the specified image."""

    def __init__(
        self,
        *,
        faces: collections.abc.Iterable[global___Face] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["faces", b"faces"]) -> None: ...

global___FaceAnnotation = FaceAnnotation

@typing.final
class Face(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    @property
    def bounding_box(self) -> yandex.cloud.ai.vision.v1.primitives_pb2.Polygon:
        """Area on the image where the face is located."""

    def __init__(
        self,
        *,
        bounding_box: yandex.cloud.ai.vision.v1.primitives_pb2.Polygon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> None: ...

global___Face = Face



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/endpoint/yds.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/endpoint/yds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import parsers_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_parsers__pb2
from yandex.cloud.datatransfer.v1.endpoint import serializers_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_serializers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/datatransfer/v1/endpoint/yds.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x33yandex/cloud/datatransfer/v1/endpoint/parsers.proto\x1a\x37yandex/cloud/datatransfer/v1/endpoint/serializers.proto\"\xe0\x02\n\tYDSSource\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12T\n\x10supported_codecs\x18\t \x03(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.YdsCompressionCodec\x12=\n\x06parser\x18\n \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Parser\x12\x18\n\x10\x61llow_ttl_rewind\x18\x0b \x01(\x08\x12\x10\n\x08\x65ndpoint\x18\x14 \x01(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x17\n\x0fsecurity_groups\x18\" \x03(\t\x12\x10\n\x08\x63onsumer\x18# \x01(\tJ\x04\x08\x03\x10\x08J\x04\x08\x0c\x10\x14J\x04\x08\x15\x10\x1eJ\x04\x08\x1f\x10\"\"\xd4\x02\n\tYDSTarget\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\x12\x15\n\rsave_tx_order\x18\x04 \x01(\x08\x12U\n\x11\x63ompression_codec\x18\x05 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.YdsCompressionCodec\x12\x45\n\nserializer\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.datatransfer.v1.endpoint.Serializer\x12\x10\n\x08\x65ndpoint\x18\x14 \x01(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x17\n\x0fsecurity_groups\x18\" \x03(\tJ\x04\x08\x06\x10\x08J\x04\x08\t\x10\x14J\x04\x08\x15\x10\x1eJ\x04\x08\x1f\x10\"*\x9b\x01\n\x13YdsCompressionCodec\x12%\n!YDS_COMPRESSION_CODEC_UNSPECIFIED\x10\x00\x12\x1d\n\x19YDS_COMPRESSION_CODEC_RAW\x10\x01\x12\x1e\n\x1aYDS_COMPRESSION_CODEC_GZIP\x10\x02\x12\x1e\n\x1aYDS_COMPRESSION_CODEC_ZSTD\x10\x04\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.yds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_YDSCOMPRESSIONCODEC']._serialized_start=899
  _globals['_YDSCOMPRESSIONCODEC']._serialized_end=1054
  _globals['_YDSSOURCE']._serialized_start=201
  _globals['_YDSSOURCE']._serialized_end=553
  _globals['_YDSTARGET']._serialized_start=556
  _globals['_YDSTARGET']._serialized_end=896
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.ai.assistants.v1.common_pb2
import yandex.cloud.ai.assistants.v1.threads.message_pb2
import yandex.cloud.ai.common.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Run(google.protobuf.message.Message):
    """Represents a run of an assistant over a specific thread of messages."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    THREAD_ID_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    CUSTOM_PROMPT_TRUNCATION_OPTIONS_FIELD_NUMBER: builtins.int
    CUSTOM_COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    CUSTOM_RESPONSE_FORMAT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the run."""
    assistant_id: builtins.str
    """Identifier for the assistant that is being run."""
    thread_id: builtins.str
    """Identifier for the thread of messages that this run is associated with."""
    created_by: builtins.str
    """Identifier of the subject who created this run."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the run was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs that can be used to organize and categorize the run."""

    @property
    def state(self) -> global___RunState:
        """Current state of the run, including its status and any associated data."""

    @property
    def usage(self) -> global___ContentUsage:
        """Information about the content usage during the run, such as the number of [tokens](/docs/foundation-models/concepts/yandexgpt/tokens) used by the completion model."""

    @property
    def custom_prompt_truncation_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions:
        """Configuration options for truncating the prompt when the token count exceeds a specified limit.
        If specified, these options will override the assistant's prompt truncation settings for this run.
        """

    @property
    def custom_completion_options(self) -> yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions:
        """Configuration options for completion generation.
        If specified, these options will override the assistant's completion settings for this run.
        """

    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.common_pb2.Tool]:
        """List of tools that are available for the assistant to use in this run."""

    @property
    def custom_response_format(self) -> yandex.cloud.ai.assistants.v1.common_pb2.ResponseFormat:
        """Specifies the format of the model's response."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        assistant_id: builtins.str = ...,
        thread_id: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        state: global___RunState | None = ...,
        usage: global___ContentUsage | None = ...,
        custom_prompt_truncation_options: yandex.cloud.ai.assistants.v1.common_pb2.PromptTruncationOptions | None = ...,
        custom_completion_options: yandex.cloud.ai.assistants.v1.common_pb2.CompletionOptions | None = ...,
        tools: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.common_pb2.Tool] | None = ...,
        custom_response_format: yandex.cloud.ai.assistants.v1.common_pb2.ResponseFormat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "custom_completion_options", b"custom_completion_options", "custom_prompt_truncation_options", b"custom_prompt_truncation_options", "custom_response_format", b"custom_response_format", "state", b"state", "usage", b"usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assistant_id", b"assistant_id", "created_at", b"created_at", "created_by", b"created_by", "custom_completion_options", b"custom_completion_options", "custom_prompt_truncation_options", b"custom_prompt_truncation_options", "custom_response_format", b"custom_response_format", "id", b"id", "labels", b"labels", "state", b"state", "thread_id", b"thread_id", "tools", b"tools", "usage", b"usage"]) -> None: ...

global___Run = Run

@typing.final
class RunState(google.protobuf.message.Message):
    """Represents the current state of a run."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RunStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RunStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RunState._RunStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RUN_STATUS_UNSPECIFIED: RunState._RunStatus.ValueType  # 0
        """Default unspecified status."""
        PENDING: RunState._RunStatus.ValueType  # 1
        """Run has been created but has not started yet."""
        IN_PROGRESS: RunState._RunStatus.ValueType  # 2
        """Run is currently in progress."""
        FAILED: RunState._RunStatus.ValueType  # 3
        """Run has failed due to an error."""
        COMPLETED: RunState._RunStatus.ValueType  # 4
        """Run has completed successfully."""
        TOOL_CALLS: RunState._RunStatus.ValueType  # 5
        """The run is waiting for tool calls to be executed and their results to be submitted."""

    class RunStatus(_RunStatus, metaclass=_RunStatusEnumTypeWrapper):
        """Enum representing the status of a run."""

    RUN_STATUS_UNSPECIFIED: RunState.RunStatus.ValueType  # 0
    """Default unspecified status."""
    PENDING: RunState.RunStatus.ValueType  # 1
    """Run has been created but has not started yet."""
    IN_PROGRESS: RunState.RunStatus.ValueType  # 2
    """Run is currently in progress."""
    FAILED: RunState.RunStatus.ValueType  # 3
    """Run has failed due to an error."""
    COMPLETED: RunState.RunStatus.ValueType  # 4
    """Run has completed successfully."""
    TOOL_CALLS: RunState.RunStatus.ValueType  # 5
    """The run is waiting for tool calls to be executed and their results to be submitted."""

    STATUS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    COMPLETED_MESSAGE_FIELD_NUMBER: builtins.int
    TOOL_CALL_LIST_FIELD_NUMBER: builtins.int
    status: global___RunState.RunStatus.ValueType
    """Current status of a run."""
    @property
    def error(self) -> yandex.cloud.ai.common.common_pb2.Error:
        """Error information if a run has failed."""

    @property
    def completed_message(self) -> yandex.cloud.ai.assistants.v1.threads.message_pb2.Message:
        """Final message generated by an assistant if a run has completed successfully."""

    @property
    def tool_call_list(self) -> yandex.cloud.ai.assistants.v1.common_pb2.ToolCallList:
        """A list of tool calls requested by the assistant."""

    def __init__(
        self,
        *,
        status: global___RunState.RunStatus.ValueType = ...,
        error: yandex.cloud.ai.common.common_pb2.Error | None = ...,
        completed_message: yandex.cloud.ai.assistants.v1.threads.message_pb2.Message | None = ...,
        tool_call_list: yandex.cloud.ai.assistants.v1.common_pb2.ToolCallList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["StateData", b"StateData", "completed_message", b"completed_message", "error", b"error", "tool_call_list", b"tool_call_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["StateData", b"StateData", "completed_message", b"completed_message", "error", b"error", "status", b"status", "tool_call_list", b"tool_call_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["StateData", b"StateData"]) -> typing.Literal["error", "completed_message", "tool_call_list"] | None: ...

global___RunState = RunState

@typing.final
class ContentUsage(google.protobuf.message.Message):
    """Represents the content usage during a run, such as the number of [tokens](/docs/foundation-models/concepts/yandexgpt/tokens) used by the completion model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_TOKENS_FIELD_NUMBER: builtins.int
    COMPLETION_TOKENS_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    prompt_tokens: builtins.int
    """The number of tokens used in the prompt."""
    completion_tokens: builtins.int
    """The number of tokens used in the completion response."""
    total_tokens: builtins.int
    """The total number of tokens used (prompt + completion)."""
    def __init__(
        self,
        *,
        prompt_tokens: builtins.int = ...,
        completion_tokens: builtins.int = ...,
        total_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["completion_tokens", b"completion_tokens", "prompt_tokens", b"prompt_tokens", "total_tokens", b"total_tokens"]) -> None: ...

global___ContentUsage = ContentUsage
